@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1997, 1998, 1999, 2000 Peter Miller;
+ *	Copyright (C) 1994, 1995, 1997, 1998, 1999, 2000, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -210,7 +210,8 @@ sniff_prepare()
  *	resolve
  *
  * SYNOPSIS
- *	string_ty *resolve(string_ty *filename, string_ty *extra, string_list_ty *srl);
+ *	string_ty *resolve(string_ty *filename, string_ty *extra,
+ *		string_list_ty *srl);
  *
  * DESCRIPTION
  *	The resolve function is used to resolve an include
@@ -676,7 +677,11 @@ sniffer(filename, prnam, result)
 					);
 				if (path)
 				{
-					string_list_append_unique(&cp->ingredients, path);
+					string_list_append_unique
+					(
+						&cp->ingredients,
+						path
+					);
 					str_free(path);
 				}
 			}
@@ -711,7 +716,11 @@ sniffer(filename, prnam, result)
 				);
 			if (path)
 			{
-				string_list_append_unique(&cp->ingredients, path);
+				string_list_append_unique
+				(
+					&cp->ingredients,
+					path
+				);
 				str_free(path);
 			}
 		}
@@ -920,7 +929,7 @@ sniff(filename)
 				fatal_intl(scp, i18n("open $filename: $errno"));
 				/* NOTREACHED */
 				break;
-	
+
 			case absent_mention:
 				scp = sub_context_new();
 				sub_errno_setx(scp, ENOENT);
@@ -928,7 +937,7 @@ sniff(filename)
 				error_intl(scp, i18n("open $filename: $errno"));
 				/* NOTREACHED */
 				break;
-	
+
 			default:
 				break;
 			}
