@@ -35,7 +35,10 @@
 
 #ifndef HAVE_WINT_T
 #define HAVE_WINT_T
+#ifndef _WINT_T
+#define _WINT_T
 typedef wchar_t wint_t;
 #endif
+#endif
 
 #endif /* COMMON_AC_STDDEF_H */
