@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1990, 1991, 1992, 1993, 1994, 1997 Peter Miller;
+ *	Copyright (C) 1990, 1991, 1992, 1993, 1994, 1997, 1999 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -24,6 +24,7 @@
 #define COMMON_ERROR_H
 
 #include <main.h>
+#include <noreturn.h>
 
 /*
  * These were the old names.  Use *_intl instead.
@@ -34,8 +35,8 @@
 #define nfatal +/+/+/+
 
 void error_raw _((char *, ...));
-void fatal_raw _((char *, ...));
+void fatal_raw _((char *, ...)) NORETURN;
 void nerror_raw _((char *, ...));
-void nfatal_raw _((char *, ...));
+void nfatal_raw _((char *, ...)) NORETURN;
 
 #endif /* COMMON_ERROR_H */
