@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994, 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1994, 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -94,7 +94,7 @@ look_for_name_map(afp, name, len)
 		memcmp(name, "ARFILENAMES/", 12)
 	)
 		return 0;
-	
+
 	/*
 	 * read the data
 	 */
@@ -1126,8 +1126,9 @@ archive_file_open(path, mode)
 	/*
 	 * open the file as specified
 	 */
-	trace(("archive_file_open(path = \"%s\", mode = %d)\n{\n"/*}*/, path->str_text, mode));
-	assert(mode == O_RDONLY || mode == O_RDWR);
+	trace(("archive_file_open(path = \"%s\", mode = %d)\n{\n"/*}*/,
+		path->str_text, mode));
+	assert(mode == (O_RDONLY | O_BINARY) || mode == (O_RDWR | O_BINARY));
 	trace(("open\n"));
 	fd = open(path->str_text, mode, 0666);
 	if (fd < 0)
@@ -1242,7 +1243,7 @@ archive_file_stat(afp, member, st)
 			goto done;
 		if (afp->method->advance(afp))
 			goto done;
-			
+
 		/*
 		 * see if it is the one we want
 		 */
@@ -1477,7 +1478,7 @@ archive_match(name, path_p, member_p)
 		mp = p + 1;
 	*member_p = str_n_from_c(mp, name->str_length - 1 - (mp - s));
 	return 1;
-}  
+}
 
 
 int
@@ -1514,7 +1515,7 @@ archive_stat(name, st)
 	 * open the archive file
 	 */
 	trace(("open\n"));
-	afp = archive_file_open(path, O_RDONLY);
+	afp = archive_file_open(path, O_RDONLY | O_BINARY);
 	if (!afp)
 	{
 		str_free(member);
@@ -1598,7 +1599,7 @@ archive_utime(name, ut)
 	/*
 	 * open the archive file
 	 */
-	afp = archive_file_open(path, O_RDWR);
+	afp = archive_file_open(path, O_RDWR | O_BINARY);
 	if (!afp)
 	{
 		str_free(member);
@@ -1677,7 +1678,7 @@ archive_fingerprint(fp, name, buf)
 	/*
 	 * open the archive file
 	 */
-	afp = archive_file_open(path, O_RDONLY);
+	afp = archive_file_open(path, O_RDONLY | O_BINARY);
 	if (!afp)
 	{
 		str_free(member);
