@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1999 Peter Miller;
+ *	Copyright (C) 1997, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -44,7 +44,8 @@ void expr_list_append _((expr_list_ty *, struct expr_ty *));
 void expr_list_destructor _((expr_list_ty *));
 void expr_list_delete _((expr_list_ty *));
 void expr_list_copy_constructor _((expr_list_ty *, const expr_list_ty *));
-struct string_list_ty *expr_list_evaluate _((const expr_list_ty *, const struct match_ty *));
+struct string_list_ty *expr_list_evaluate _((const expr_list_ty *,
+	const struct match_ty *));
 void expr_list_constructor _((expr_list_ty *));
 expr_list_ty *expr_list_new _((void));
 void expr_list_code_generate _((const expr_list_ty *, struct opcode_list_ty *));
