@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1999 Peter Miller;
+ *	Copyright (C) 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -45,7 +45,8 @@ fp_value_constructor(this)
 	trace(("fp_value_constructor(this = %08lX)\n{\n", (long)this));
 	this->oldest = 0;
 	this->newest = 0;
-	this->fingerprint = 0;
+	this->contents_fingerprint = 0;
+	this->ingredients_fingerprint = 0;
 	trace(("}\n"));
 }
 
@@ -72,7 +73,22 @@ fp_value_constructor_copy(this, fp)
 		(long)this, (long)fp));
 	this->oldest = fp->oldest;
 	this->newest = fp->newest;
-	this->fingerprint = (fp->fingerprint ? str_copy(fp->fingerprint) : 0);
+	this->contents_fingerprint =
+		(
+			fp->contents_fingerprint
+		?
+			str_copy(fp->contents_fingerprint)
+		:
+			0
+		);
+	this->ingredients_fingerprint =
+		(
+			fp->ingredients_fingerprint
+		?
+			str_copy(fp->ingredients_fingerprint)
+		:
+			0
+		);
 	trace(("}\n"));
 }
 
@@ -96,12 +112,50 @@ fp_value_constructor3(this, a1, a2, a3)
 	time_t		a2;
 	string_ty	*a3;
 {
-	trace(("fp_value_constructor3(this = %08lX, oldest = %ld, youngest = %ld, crypto = \"%s\")\n{\n", (long)this, a1, a2, (a3 ? a3->str_text : "")));
+	trace(("fp_value_constructor3(this = %08lX, oldest = %ld, \
+youngest = %ld, crypto = \"%s\")\n{\n", (long)this, a1, a2,
+		(a3 ? a3->str_text : "")));
 	if (a1 > a2)
 		a1 = a2;
 	this->oldest = a1;
 	this->newest = a2;
-	this->fingerprint = (a3 ? str_copy(a3) : 0);
+	this->contents_fingerprint = (a3 ? str_copy(a3) : 0);
+	this->ingredients_fingerprint = 0;
+	trace(("}\n"));
+}
+
+
+/*
+ * NAME
+ *	fp_value_constructor4
+ *
+ * SYNOPSIS
+ *	void fp_value_constructor4(fp_value_ty *, time_t, time_t, string_ty *,
+ *		string_ty *);
+ *
+ * DESCRIPTION
+ *	The fp_value_constructor4 function is used to initialize a
+ *	fp_value_ty structure with explicit instance variable values.
+ */
+
+void
+fp_value_constructor4(this, a1, a2, a3, a4)
+	fp_value_ty	*this;
+	time_t		a1;
+	time_t		a2;
+	string_ty	*a3;
+	string_ty	*a4;
+{
+	trace(("fp_value_constructor4(this = %08lX, oldest = %ld, youngest = \
+%ld, cfp = \"%s\", ifp = \"%s\")\n{\n",
+		(long)this, a1, a2, (a3 ? a3->str_text : ""),
+		(a4 ? a4->str_text : "")));
+	if (a1 > a2)
+		a1 = a2;
+	this->oldest = a1;
+	this->newest = a2;
+	this->contents_fingerprint = (a3 ? str_copy(a3) : 0);
+	this->ingredients_fingerprint = (a4 ? str_copy(a4) : 0);
 	trace(("}\n"));
 }
 
@@ -125,9 +179,12 @@ fp_value_destructor(this)
 	trace(("fp_value_destructor(this = %08lX)\n{\n", (long)this));
 	this->oldest = 0;
 	this->newest = 0;
-	if (this->fingerprint)
-		str_free(this->fingerprint);
-	this->fingerprint = 0;
+	if (this->contents_fingerprint)
+		str_free(this->contents_fingerprint);
+	this->contents_fingerprint = 0;
+	if (this->ingredients_fingerprint)
+		str_free(this->ingredients_fingerprint);
+	this->ingredients_fingerprint = 0;
 	trace(("}\n"));
 }
 
@@ -201,7 +258,8 @@ fp_value_copy(to, from)
 	fp_value_ty	*to;
 	const fp_value_ty *from;
 {
-	trace(("fp_value_copy(to = %08lX, from = %08lX)\n{\n", (long)to, (long)from));
+	trace(("fp_value_copy(to = %08lX, from = %08lX)\n{\n",
+		(long)to, (long)from));
 	if (from == to)
 	{
 		trace(("}\n"));
@@ -209,12 +267,21 @@ fp_value_copy(to, from)
 	}
 	to->newest = from->newest;
 	to->oldest = from->oldest;
-	if (to->fingerprint)
-		str_free(to->fingerprint);
-	if (from->fingerprint)
-		to->fingerprint = str_copy(from->fingerprint);
+
+	if (to->contents_fingerprint)
+		str_free(to->contents_fingerprint);
+	if (from->contents_fingerprint)
+		to->contents_fingerprint = str_copy(from->contents_fingerprint);
 	else
-		to->fingerprint = 0;
+		to->contents_fingerprint = 0;
+
+	if (to->ingredients_fingerprint)
+		str_free(to->ingredients_fingerprint);
+	if (from->ingredients_fingerprint)
+		to->ingredients_fingerprint =
+			str_copy(from->ingredients_fingerprint);
+	else
+		to->ingredients_fingerprint = 0;
 	trace(("}\n"));
 }
 
@@ -239,34 +306,35 @@ fp_value_write(this, key, fp)
 	string_ty	*key;
 	FILE		*fp;
 {
+	if (!this->contents_fingerprint && !this->ingredients_fingerprint)
+		return;
 	trace(("fp_value_write(this = %08lX, key = \"%s\", fp = %08lX)\n{\n",
 		(long)this, key->str_text, (long)fp));
-	if (this->fingerprint)
+	fprintf(fp, "\"%s\" = { %ld", key->str_text, (long)this->oldest);
+	if (this->oldest < this->newest)
+		fprintf(fp, " %ld", (long)this->newest);
+	fprintf
+	(
+		fp,
+		"\n\"%s\"",
+		(
+			this->contents_fingerprint
+		?
+			this->contents_fingerprint->str_text
+		:
+			""
+		)
+	);
+	if (this->ingredients_fingerprint)
 	{
-		if (this->oldest >= this->newest)
-		{
-			fprintf
-			(
-				fp,
-				"\"%s\" = { %ld\n\"%s\" }\n",
-				key->str_text,
-				(long)this->newest,
-				this->fingerprint->str_text
-			);
-		}
-		else
-		{
-			fprintf
-			(
-				fp,
-				"\"%s\" = { %ld %ld\n\"%s\" }\n",
-				key->str_text,
-				(long)this->oldest,
-				(long)this->newest,
-				this->fingerprint->str_text
-			);
-		}
+		fprintf
+		(
+			fp,
+			"\n\"%s\"",
+			this->ingredients_fingerprint->str_text
+		);
 	}
+	fprintf(fp, " }\n");
 	trace(("}\n"));
 }
 
@@ -287,9 +355,10 @@ fp_value_equal(v1, v2)
 	const fp_value_ty *v1;
 	const fp_value_ty *v2;
 {
+	/* DON'T compare the ingredients FP */
 	return
 	(
-		str_equal(v1->fingerprint, v2->fingerprint)
+		str_equal(v1->contents_fingerprint, v2->contents_fingerprint)
 	&&
 		v1->newest == v2->newest
 	&&
