@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -25,6 +25,7 @@
 #include <cook.h>
 #include <dir_part.h>
 #include <error_intl.h>
+#include <fingerprint.h>
 #include <graph.h>
 #include <graph/file.h>
 #include <graph/file_list.h>
@@ -60,10 +61,12 @@ make_target_directories(gflp)
 	errok = option_test(OPTION_ERROK);
 	for (k = 0; k < gflp->nfiles; ++k)
 	{
+		graph_file_and_type_ty *gftp;
 		graph_file_ty	*gfp;
 		string_ty	*s;
-	
-		gfp = gflp->file[k];
+
+		gftp = gflp->item + k;
+		gfp = gftp->file;
 		s = dir_part(gfp->filename);
 		if (s)
 		{
@@ -172,14 +175,14 @@ graph_recipe_run(grp, gp)
 	{
 		for (j = 0; j < grp->output->nfiles; ++j)
 		{
-			target1 = grp->output->file[j]->filename;
+			target1 = grp->output->item[j].file->filename;
 			for (k = 0; k < grp->input->nfiles; ++k)
 			{
 				graph_file_pair_check
 				(
 					gp->file_pair,
 					target1,
-					grp->input->file[k]->filename,
+					grp->input->item[k].file->filename,
 					gp
 				);
 			}
@@ -194,7 +197,7 @@ graph_recipe_run(grp, gp)
 	assert(grp->output->nfiles > 0);
 	if (grp->output->nfiles > 0)
 	{
-		target1 = grp->output->file[0]->filename;
+		target1 = grp->output->item[0].file->filename;
 		string_list_append(&wl, target1);
 	}
 	else
@@ -208,8 +211,14 @@ graph_recipe_run(grp, gp)
 	string_list_constructor(&wl);
 	assert(grp->input);
 	for (j = 0; j < grp->output->nfiles; ++j)
-		string_list_append(&wl, grp->output->file[j]->filename);
-	opcode_context_id_assign(grp->ocp, id_targets, id_variable_new(&wl), -1);
+		string_list_append(&wl, grp->output->item[j].file->filename);
+	opcode_context_id_assign
+	(
+		grp->ocp,
+		id_targets,
+		id_variable_new(&wl),
+		-1
+	);
 	string_list_destructor(&wl);
 
 	/*
@@ -218,7 +227,7 @@ graph_recipe_run(grp, gp)
 	string_list_constructor(&wl);
 	assert(grp->input);
 	for (j = 0; j < grp->input->nfiles; ++j)
-		string_list_append(&wl, grp->input->file[j]->filename);
+		string_list_append(&wl, grp->input->item[j].file->filename);
 	opcode_context_id_assign(grp->ocp, id_need, id_variable_new(&wl), -1);
 	string_list_destructor(&wl);
 
@@ -228,7 +237,13 @@ graph_recipe_run(grp, gp)
 	 * times.  [[Fake an assignment to avoid problems with errors.]]
 	 */
 	string_list_constructor(&younger);
-	opcode_context_id_assign(grp->ocp, id_younger, id_variable_new(&younger), -1);
+	opcode_context_id_assign
+	(
+		grp->ocp,
+		id_younger,
+		id_variable_new(&younger),
+		-1
+	);
 
 	/*
 	 * Flags apply to the precondition and to the ingredients
@@ -254,6 +269,59 @@ i18n("\"$filename\" is out of date because the \"forced\" flag is set (reason)")
 		sub_context_delete(scp);
 	}
 
+	/*
+         * By taking a fingerprint of the ingredients, we can cause
+         * the recipe to trigger when the number of ingredients change,
+         * or when one ingredient is substituted for another, EVEN IF
+         * the time stamps are all consistent.	(This is especially
+         * important when an ingredient is *removed* from a library.)
+         */
+	if (option_test(OPTION_INGREDIENTS_FINGERPRINT))
+	{
+		string_list_ty	ingr;
+		string_ty	*ingr2;
+		string_ty	*ingr_fp;
+
+		string_list_constructor(&ingr);
+		for (j = 0; j < grp->input->nfiles; ++j)
+		{
+			graph_file_ty *gfp;
+
+			gfp = grp->input->item[j].file;
+			string_list_append(&ingr, gfp->filename);
+		}
+		string_list_sort(&ingr);
+		ingr2 = wl2str(&ingr, 0, ingr.nstrings, "\n");
+		string_list_destructor(&ingr);
+		ingr_fp = fp_fingerprint_string(ingr2);
+		str_free(ingr2);
+
+		/*
+		 * Not only does the fp_ingredients_fingerprint_differs
+		 * function check to see if it is different, it also
+		 * updates the cache files, so that it will be written
+		 * out at the next opportunity.
+		 */
+		if (fp_ingredients_fingerprint_differs(target1, ingr_fp))
+		{
+			forced = 1;
+
+			if (show_reasoning)
+			{
+				scp = sub_context_new();
+				sub_var_set(scp, "File_Name", "%S", target1);
+				error_with_position
+				(
+					&grp->rp->pos,
+					scp,
+   i18n("\"$filename\" is out of date because the ingredients changed (reason)")
+				);
+				sub_context_delete(scp);
+			}
+		}
+		str_free(ingr_fp);
+	}
+
 	/*
 	 * age should be set to the worst case of all the targets
 	 *
@@ -271,7 +339,7 @@ i18n("\"$filename\" is out of date because the \"forced\" flag is set (reason)")
 		time_t		age2;
 		long		depth2;
 
-		gfp2 = grp->output->file[j];
+		gfp2 = grp->output->item[j].file;
 
 		/*
 		 * Remember the oldest mtime for later, when we compare
@@ -282,7 +350,14 @@ i18n("\"$filename\" is out of date because the \"forced\" flag is set (reason)")
 		if (option_test(OPTION_FINGERPRINT))
 		{
 			depth2 = 32767;
-			age2 = cook_mtime_oldest(grp->ocp, gfp2->filename, &depth2, depth2);
+			age2 =
+				cook_mtime_oldest
+				(
+					grp->ocp,
+					gfp2->filename,
+					&depth2,
+					depth2
+				);
 			if (age2 < 0)
 			{
 				/* error message already printed */
@@ -291,9 +366,16 @@ i18n("\"$filename\" is out of date because the \"forced\" flag is set (reason)")
 			}
 			gfp2->mtime_oldest = age2;
 		}
-		
+
 		depth2 = 32767;
-		age2 = cook_mtime_newest(grp->ocp, gfp2->filename, &depth2, depth2);
+		age2 =
+			cook_mtime_newest
+			(
+				grp->ocp,
+				gfp2->filename,
+				&depth2,
+				depth2
+			);
 		if (age2 < 0)
 		{
 			/* error message already printed */
@@ -358,13 +440,23 @@ i18n("\"$filename\" is out of date because the \"forced\" flag is set (reason)")
 	need_age = 0;
 	for (j = 0; j < grp->input->nfiles; ++j)
 	{
+		graph_file_and_type_ty *gftp2;
 		graph_file_ty	*gfp2;
 		time_t		age2;
 		long		depth2;
+		int		do_this_one;
 
-		gfp2 = grp->input->file[j];
+		gftp2 = grp->input->item + j;
+		gfp2 = gftp2->file;
 		depth2 = 32767;
-		age2 = cook_mtime_oldest(grp->ocp, gfp2->filename, &depth2, target_depth+1);
+		age2 =
+			cook_mtime_oldest
+			(
+				grp->ocp,
+				gfp2->filename,
+				&depth2,
+				target_depth + 1
+			);
 		if (age2 < 0)
 		{
 			/* error message already printed */
@@ -393,7 +485,7 @@ i18n("\"$filename\" is out of date because the \"forced\" flag is set (reason)")
 		 * target, based on its age.  (Don't say anything if we
 		 * already know it's out of date.)
 		 */
-		if (gfp2->done)
+		if (gfp2->done && gftp2->edge_type != edge_type_exists)
 		{
 			if (!forced)
 			{
@@ -432,8 +524,39 @@ now younger (reason)")
 		 * Check to see if this ingredient invalidates the
 		 * target, based on its age.  (Don't say anything if we
 		 * already know it's out of date.)
+		 * The edge type is relevant to the calculation.
 		 */
-		if (age2 >= target_age && !phony)
+		do_this_one = 0;
+		switch (gftp2->edge_type)
+		{
+		case edge_type_exists:
+			/*
+			 * The "exists" edge type is merely an ordering
+			 * constraint.	It guarantees that the ingredient
+			 * will be up to date before this recipie's body
+			 * is evaluated.  The actual relative ages of the
+			 * ingredient and the target don't come into it.
+			 */
+			break;
+
+		case edge_type_weak:
+			/*
+			 * The "weak" edge type allows two files to have
+			 * the same time stamp, and still be up-to-date.
+			 */
+			do_this_one = age2 > target_age;
+			break;
+
+		case edge_type_strict:
+		case edge_type_default:
+			/*
+			 * The "strict" edge type requires two files to
+			 * have distinct time stamps.
+			 */
+			do_this_one = age2 >= target_age;
+			break;
+		}
+		if (do_this_one && !phony)
 		{
 			if (!forced)
 			{
@@ -525,7 +648,13 @@ now younger (reason)")
 	 * Assign the ``younger'' variable.
 	 * (Use a normal assignment, we did the push already.)
 	 */
-	opcode_context_id_assign(grp->ocp, id_younger, id_variable_new(&younger), -1);
+	opcode_context_id_assign
+	(
+		grp->ocp,
+		id_younger,
+		id_variable_new(&younger),
+		-1
+	);
 	string_list_destructor(&younger);
 
 	/*
@@ -563,8 +692,8 @@ now younger (reason)")
 				for (k = 0; k < grp->output->nfiles; ++k)
 				{
 					graph_file_ty	*gfp2;
-	
-					gfp2 = grp->output->file[k];
+
+					gfp2 = grp->output->item[k].file;
 					if
 					(
 						os_delete
@@ -592,8 +721,8 @@ now younger (reason)")
 				for (k = 0; k < grp->output->nfiles; ++k)
 				{
 					graph_file_ty	*gfp2;
-	
-					gfp2 = grp->output->file[k];
+
+					gfp2 = grp->output->item[k].file;
 					if (!option_test(OPTION_SILENT))
 					{
 						scp = sub_context_new();
@@ -620,12 +749,16 @@ now younger (reason)")
 			{
 				opcode_status_ty result;
 				string_ty	*hostname;
-	
+
 				/*
 				 * run the recipe body
 				 */
 				trace(("doing it now\n"));
-				opcode_context_call(grp->ocp, grp->rp->out_of_date);
+				opcode_context_call
+				(
+					grp->ocp,
+					grp->rp->out_of_date
+				);
 				hostname =
 					host_binding_round_robin
 					(
@@ -654,7 +787,7 @@ now younger (reason)")
 				case opcode_status_success:
 					status = graph_walk_status_done;
 					break;
-	
+
 				case opcode_status_error:
 					if (option_test(OPTION_ERROK))
 						status = graph_walk_status_done;
@@ -693,8 +826,9 @@ now younger (reason)")
 					)
 					{
 						graph_file_ty	*gfp2;
-	
-						gfp2 = grp->output->file[k];
+
+						gfp2 =
+						      grp->output->item[k].file;
 						os_delete
 						(
 							gfp2->filename,
@@ -710,7 +844,11 @@ now younger (reason)")
 			{
 				scp = sub_context_new();
 				sub_var_set(scp, "File_Name", "%S", target1);
-				error_intl(scp, i18n("$filename is phony (reason)"));
+				error_intl
+				(
+					scp,
+					i18n("$filename is phony (reason)")
+				);
 				sub_context_delete(scp);
 			}
 
@@ -721,7 +859,7 @@ now younger (reason)")
 			{
 				graph_file_ty	*gfp;
 
-				gfp = grp->output->file[j];
+				gfp = grp->output->item[j].file;
 				gfp->done++;
 			}
 		}
@@ -800,7 +938,7 @@ ret:
 				time_t		t;
 				long		depth4;
 
-				gfp = grp->output->file[j];
+				gfp = grp->output->item[j].file;
 				os_clear_stat(gfp->filename);
 				if (os_mtime_adjust(gfp->filename, mtime))
 				{
@@ -812,7 +950,14 @@ ret:
 					continue;
 				}
 				depth4 = 32767;
-				t = cook_mtime_oldest(grp->ocp, gfp->filename, &depth4, depth4);
+				t =
+					cook_mtime_oldest
+					(
+						grp->ocp,
+						gfp->filename,
+						&depth4,
+						depth4
+					);
 				if (t < 0)
 				{
 					status = graph_walk_status_error;
@@ -859,7 +1004,7 @@ ret:
 			{
 				graph_file_ty	*gfp;
 
-				gfp = grp->output->file[j];
+				gfp = grp->output->item[j].file;
 				gfp->done++; /* for out-of-date calcs */
 				if (os_mtime_adjust(gfp->filename, mtime))
 				{
@@ -908,13 +1053,22 @@ ret:
 		need_age_youngest = 0;
 		for (j = 0; j < grp->input->nfiles; ++j)
 		{
+			graph_file_and_type_ty *gftp2;
 			graph_file_ty	*gfp2;
 			time_t		age2;
 			long		depth2;
-	
-			gfp2 = grp->input->file[j];
+
+			gftp2 = grp->input->item + j;
+			gfp2 = gftp2->file;
 			depth2 = 32767;
-			age2 = cook_mtime_newest(grp->ocp, gfp2->filename, &depth2, depth2);
+			age2 =
+				cook_mtime_newest
+				(
+					grp->ocp,
+					gfp2->filename,
+					&depth2,
+					depth2
+				);
 			if (age2 > need_age_youngest)
 				need_age_youngest = age2;
 		}
@@ -935,11 +1089,24 @@ ret:
 			time_t		age3;
 			long		depth3;
 
-			gfp = grp->output->file[j];
+			gfp = grp->output->item[j].file;
 			depth3 = 32767;
-			age3 = cook_mtime_newest(grp->ocp, gfp->filename, &depth3, depth3);
+			age3 =
+				cook_mtime_newest
+				(
+					grp->ocp,
+					gfp->filename,
+					&depth3,
+					depth3
+				);
 			if (age3 > 0 && depth3 == 0 && age3 < need_age_youngest)
-				os_mtime_adjust(gfp->filename, need_age_youngest);
+			{
+				os_mtime_adjust
+				(
+					gfp->filename,
+					need_age_youngest
+				);
+			}
 		}
 	}
 
