@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -117,22 +117,26 @@ static arglex_table_ty argtab[] =
 	{ "-Continue",		(arglex_token_ty)arglex_token_persevere, },
 	{ "-No_Continue",	(arglex_token_ty)arglex_token_persevere_not, },
 	{ "-DISassemble",	(arglex_token_ty)arglex_token_disassemble, },
-	{ "-No_DISassemble",	(arglex_token_ty)arglex_token_disassemble_not, },
+	{ "-No_DISassemble",   (arglex_token_ty)arglex_token_disassemble_not, },
 	{ "-Errok",		(arglex_token_ty)arglex_token_errok,	},
-	{ "-No_Errok",		(arglex_token_ty)arglex_token_errok_not,	},
+	{ "-No_Errok",		(arglex_token_ty)arglex_token_errok_not, },
 	{ "-FingerPrint",	(arglex_token_ty)arglex_token_fingerprint, },
-	{ "-No_FingerPrint",	(arglex_token_ty)arglex_token_fingerprint_not, },
-	{ "-FingerPrint_Update", (arglex_token_ty)arglex_token_fingerprint_update, },
+	{ "-No_FingerPrint",   (arglex_token_ty)arglex_token_fingerprint_not, },
+	{ "-FingerPrint_Update",
+			    (arglex_token_ty)arglex_token_fingerprint_update, },
 	{ "-Forced",		(arglex_token_ty)arglex_token_force,	},
-	{ "-No_Forced",		(arglex_token_ty)arglex_token_force_not,	},
+	{ "-No_Forced",		(arglex_token_ty)arglex_token_force_not, },
 	{ "-HyperText_Markup_Language", (arglex_token_ty)arglex_token_web, },
 	{ "-Include",		(arglex_token_ty)arglex_token_include,	},
 	{ "-\\I*",		(arglex_token_ty)arglex_token_include,	},
 	{ "-Include_Cooked",	(arglex_token_ty)arglex_token_include_cooked, },
-	{ "-Include_Cooked_Warning", (arglex_token_ty)arglex_token_include_cooked_warning, },
+	{ "-Include_Cooked_Warning",
+			(arglex_token_ty)arglex_token_include_cooked_warning, },
 	{ "-Jobs",		(arglex_token_ty)arglex_token_parallel, },
-	{ "-No_Include_Cooked",	(arglex_token_ty)arglex_token_include_cooked_not, },
-	{ "-No_Include_Cooked_Warning", (arglex_token_ty)arglex_token_include_cooked_warning_not, },
+	{ "-No_Include_Cooked",
+			    (arglex_token_ty)arglex_token_include_cooked_not, },
+	{ "-No_Include_Cooked_Warning",
+		    (arglex_token_ty)arglex_token_include_cooked_warning_not, },
 	{ "-LOg",		(arglex_token_ty)arglex_token_log,	},
 	{ "-List",		(arglex_token_ty)arglex_token_log,	},
 	{ "-No_LOg",		(arglex_token_ty)arglex_token_log_not,	},
@@ -158,9 +162,9 @@ static arglex_table_ty argtab[] =
 	{ "-TErminal",		(arglex_token_ty)arglex_token_tty,	},
 	{ "-No_TErminal",	(arglex_token_ty)arglex_token_tty_not,	},
 	{ "-Touch",		(arglex_token_ty)arglex_token_touch,	},
-	{ "-No_Touch",		(arglex_token_ty)arglex_token_touch_not,	},
+	{ "-No_Touch",		(arglex_token_ty)arglex_token_touch_not, },
 	{ "-TRace",		(arglex_token_ty)arglex_token_reason,	},
-	{ "-No_TRace",		(arglex_token_ty)arglex_token_reason_not,	},
+	{ "-No_TRace",		(arglex_token_ty)arglex_token_reason_not, },
 	{ "-Update",		(arglex_token_ty)arglex_token_update,	},
 	{ "-Time_Adjust",	(arglex_token_ty)arglex_token_update,	},
 	{ "-No_Update",		(arglex_token_ty)arglex_token_update_not, },
@@ -193,7 +197,12 @@ usage()
 	char		*progname;
 
 	progname = progname_get();
-	fprintf(stderr, "usage: %s [ <option>... ][ <filename>... ]\n", progname);
+	fprintf
+	(
+		stderr,
+		"usage: %s [ <option>... ][ <filename>... ]\n",
+		progname
+	);
 	fprintf(stderr, "       %s -Help\n", progname);
 	fprintf(stderr, "       %s -VERSion\n", progname);
 	quit(1);
@@ -245,7 +254,7 @@ argparse(level)
 		}
 		help((char *)0, usage);
 		quit(0);
-	
+
 	case arglex_token_version:
 		if (level != OPTION_LEVEL_COMMAND_LINE)
 			goto not_in_env;
@@ -540,7 +549,12 @@ argparse(level)
 				str_free(s);
 				continue;
 			}
-			s = str_format("parallel_jobs=%d", (int)arglex_value.alv_number);
+			s =
+				str_format
+				(
+					"parallel_jobs=%d",
+					(int)arglex_value.alv_number
+				);
 			string_list_append(&option.o_vardef, s);
 			str_free(s);
 			break;
@@ -574,7 +588,13 @@ set_command_line_goals()
 
 	name = str_from_c("command-line-goals");
 	ocp = opcode_context_new(0, 0);
-	opcode_context_id_assign(ocp, name, id_variable_new(&option.o_target), 0);
+	opcode_context_id_assign
+	(
+		ocp,
+		name,
+		id_variable_new(&option.o_target),
+		0
+	);
 	opcode_context_delete(ocp);
 	str_free(name);
 }
@@ -624,7 +644,7 @@ main(argc, argv)
 	 */
 	progname_set(argv[0]);
 	str_initialize();
-	id_initialize(); 
+	id_initialize();
 	lex_initialize();
 
 	/*
@@ -685,18 +705,24 @@ main(argc, argv)
 			string_ty	*value;
 			string_list_ty	wl;
 			opcode_context_ty *ocp;
-	
+
 			s = option.o_vardef.string[j]->str_text;
 			cp = strchr(s, '=');
 			assert(cp);
 			if (!cp)
 				continue;
-			name = str_n_from_c(s, cp - s); 
+			name = str_n_from_c(s, cp - s);
 			value = str_from_c(cp + 1);
 			str2wl(&wl, value, (char *)0, 0);
 			str_free(value);
 			ocp = opcode_context_new(0, 0);
-			opcode_context_id_assign(ocp, name, id_variable_new(&wl), 0);
+			opcode_context_id_assign
+			(
+				ocp,
+				name,
+				id_variable_new(&wl),
+				0
+			);
 			opcode_context_delete(ocp);
 			str_free(name);
 			string_list_destructor(&wl);
