@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -47,7 +47,6 @@
 #include <opcode/private.h>
 #include <option.h>
 #include <os_interface.h>
-#include <quote.h>
 #include <star.h>
 #include <str_list.h>
 #include <trace.h>
@@ -382,7 +381,7 @@ spawn(args, input, pid_p, host_binding, ocp)
 				cwd,
 				result_fn
 			);
-		rcmdq = quote(rcmd);
+		rcmdq = str_quote_shell(rcmd);
 		str_free(rcmd);
 		string_list_append(&cmd, rcmdq);
 		str_free(rcmdq);
@@ -537,7 +536,11 @@ spawn(args, input, pid_p, host_binding, ocp)
 				/* re-use substitution context */
 				sub_errno_setx(scp, err);
 				sub_var_set(scp, "File_Name", "%S", fn0);
-				fatal_intl(scp, i18n("close $filename: $errno"));
+				fatal_intl
+				(
+					scp,
+					i18n("close $filename: $errno")
+				);
 				/* NOTREACHED */
 				sub_context_delete(scp);
 				str_free(fn0);
@@ -647,7 +650,7 @@ meter_print(rup)
 {
 	double		usr;
 	double		sys;
-	
+
 	usr = rup->ru_utime.tv_sec + rup->ru_utime.tv_usec * 1.0e-6;
 	meter_ptime(usr, "usr");
 	sys = rup->ru_stime.tv_sec + rup->ru_stime.tv_usec * 1.0e-6;
@@ -770,7 +773,7 @@ execute(op, ocp)
 		if (option_test(OPTION_INVALIDATE_STAT_CACHE))
 		{
 			size_t		j;
-	
+
 			for (j = 0; j < wlp->nstrings; ++j)
 				if (os_clear_stat(wlp->string[j]))
 					status = opcode_status_error;
@@ -790,7 +793,7 @@ execute(op, ocp)
 		status = spawn(wlp, isp, &ocp->pid, ocp->host_binding, ocp);
 		if (status == opcode_status_wait)
 		{
-			trace(("...wait\n")); 
+			trace(("...wait\n"));
 			ocp->wlp = wlp;
 			wlp = 0;
 			goto done;
@@ -926,7 +929,7 @@ script(op, ocp)
 		string_ty	*s2;
 
 		s1 = wl2str(wlp, 0, wlp->nstrings, " ");
-		s2 = quoted(s1);
+		s2 = str_quote_shell(s1);
 		str_free(s1);
 		printf("echo %s\n", s2->str_text);
 		str_free(s2);
@@ -953,9 +956,20 @@ script(op, ocp)
 			time(&t);
 			if (t < 0)
 				t = 0;
-			sprintf(fubar, "fubar%ldfubar%ldfubar", (long)t, (long)t);
+			sprintf
+			(
+				fubar,
+				"fubar%ldfubar%ldfubar",
+				(long)t,
+				(long)t
+			);
 
-			nl = (isp->str_length && isp->str_text[isp->str_length - 1] != '\n');
+			nl =
+				(
+				    isp->str_length
+				&&
+				    isp->str_text[isp->str_length - 1] != '\n'
+				);
 			printf
 			(
 				" << '%s'\n%s%s%s",
