@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999, 2000 Peter Miller;
+ *	Copyright (C) 1995, 1996, 1997, 1998, 1999, 2000, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -112,7 +112,7 @@ adjust_message(path, nsec)
 	 * work out the direction of adjustment
 	 */
 	trace(("adjust_message(nsec = %ld)\n{\n", nsec));
-	if (nsec >= 0) 
+	if (nsec >= 0)
 		direction = 1;
 	else
 	{
@@ -126,7 +126,13 @@ adjust_message(path, nsec)
 	scp = sub_context_new();
 	if (nsec >= (365L * 24 * 60 * 60))
 	{
-		sub_var_set(scp, "Number", "%4.2f", nsec / (double)(365L * 24 * 60 * 60));
+		sub_var_set
+		(
+			scp,
+			"Number",
+			"%4.2f",
+			nsec / (double)(365L * 24 * 60 * 60)
+		);
 		buffer = subst_intl(scp, i18n("$number years"));
 	}
 	else if (nsec >= (24L * 60 * 60))
@@ -139,13 +145,23 @@ adjust_message(path, nsec)
 	{
 		sub_var_set(scp, "Number1", "%ld", nsec / (60 * 60));
 		sub_var_set(scp, "Number2", "%ld", (nsec / 60) % 60);
-		buffer = subst_intl(scp, i18n("$number1 hours $number2 minutes"));
+		buffer =
+			subst_intl
+			(
+				scp,
+				i18n("$number1 hours $number2 minutes")
+			);
 	}
 	else if (nsec >= 60)
 	{
 		sub_var_set(scp, "Number1", "%ld", nsec / 60);
 		sub_var_set(scp, "Number2", "%ld", nsec % 60);
-		buffer = subst_intl(scp, i18n("$number1 minutes $number2 seconds"));
+		buffer =
+			subst_intl
+			(
+				scp,
+				i18n("$number1 minutes $number2 seconds")
+			);
 	}
 	else
 	{
@@ -160,10 +176,17 @@ adjust_message(path, nsec)
 	trace(("mark\n"));
 	sub_var_set(scp, "File_Name", "%S", path);
 	sub_var_set(scp, "Number", "%S", buffer);
-	if (direction < 0)
-		error_intl(scp, i18n("adjusting \"$filename\" back $number"));
-	else
-		error_intl(scp, i18n("adjusting \"$filename\" forward $number"));
+	error_intl
+	(
+		scp,
+		(
+			direction < 0
+		?
+			i18n("adjusting \"$filename\" back $number")
+		:
+			i18n("adjusting \"$filename\" forward $number")
+		)
+	);
 	str_free(buffer);
 	sub_context_delete(scp);
 	trace(("}\n"));
@@ -219,7 +242,7 @@ utimes4cygwin(path, ut)
 			return err;
 		}
 		str_free(fullpath);
-	}	
+	}
 }
 
 #endif
@@ -274,7 +297,13 @@ os_mtime_adjust(path, min_age)
 				struct utimbuf	ut;
 
 				if (!option_test(OPTION_SILENT))
-					adjust_message(path, (long)min_age - (long)mtime);
+				{
+					adjust_message
+					(
+						path,
+						(long)min_age - (long)mtime
+					);
+				}
 				ut.modtime = min_age;
 				ut.actime = min_age;
 				err = utime(path->str_text, &ut);
@@ -305,7 +334,13 @@ os_mtime_adjust(path, min_age)
 					 */
 					scp = sub_context_new();
 					sub_errno_set(scp);
-					sub_var_set(scp, "File_Name", "%S", path);
+					sub_var_set
+					(
+						scp,
+						"File_Name",
+						"%S",
+						path
+					);
 					error_intl
 					(
 						scp,
@@ -321,7 +356,13 @@ os_mtime_adjust(path, min_age)
 
 					scp = sub_context_new();
 					sub_errno_set(scp);
-					sub_var_set(scp, "File_Name", "%S", path);
+					sub_var_set
+					(
+						scp,
+						"File_Name",
+						"%S",
+						path
+					);
 					error_intl
 					(
 						scp,
@@ -436,7 +477,7 @@ os_touch(path)
 	if (err)
 	{
 		sub_context_ty	*scp;
-		
+
 		if (errno == ENOENT)
 		{
 			stat_cache_clear(path);
@@ -689,7 +730,11 @@ execute(cmd, fd, errok)
 				/* re-use substitution context */
 				sub_errno_setx(scp, err);
 				sub_var_set(scp, "File_Name", "%S", fn0);
-				fatal_intl(scp, i18n("close $filename: $errno"));
+				fatal_intl
+				(
+					scp,
+					i18n("close $filename: $errno")
+				);
 				sub_context_delete(scp);
 				str_free(fn0);
 			}
@@ -1042,7 +1087,14 @@ os_dirname(path)
 	if (cp)
 	{
 		if (cp > path->str_text)
-			path = str_n_from_c(path->str_text, cp - path->str_text);
+		{
+			path =
+				str_n_from_c
+				(
+					path->str_text,
+					cp - path->str_text
+				);
+		}
 		else
 			path = str_from_c("/");
 	}
@@ -1257,7 +1309,13 @@ os_mkdir(p, echo)
 
 					scp = sub_context_new();
 					sub_errno_set(scp);
-					sub_var_set(scp, "File_Name", "%S", tmp);
+					sub_var_set
+					(
+						scp,
+						"File_Name",
+						"%S",
+						tmp
+					);
 					error_intl
 					(
 						scp,
