@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1991, 1992, 1993, 1994, 1997, 1998, 1999 Peter Miller;
+ *	Copyright (C) 1992, 1993, 1994, 1997, 1998, 1999, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -152,7 +152,7 @@ stat_cache_fingerprint(path, cp)
 			s = fp_fingerprint(path);
 			if (!s)
 				goto fp_not_useful;
-			if (str_equal(fp->fingerprint, s))
+			if (str_equal(fp->contents_fingerprint, s))
 			{
 				cp->newest = fp->newest;
 				cp->oldest = cp->newest;
@@ -163,12 +163,13 @@ stat_cache_fingerprint(path, cp)
 
 				time(&cp->newest);
 				cp->oldest = cp->newest;
-				fp_value_constructor3
+				fp_value_constructor4
 				(
 					&data,
 					cp->oldest,
 					cp->newest,
-					s
+					s,
+					fp->ingredients_fingerprint
 				);
 				fp_assign(path, &data);
 				fp_value_destructor(&data);
@@ -187,19 +188,20 @@ stat_cache_fingerprint(path, cp)
 			s = fp_fingerprint(path);
 			if (!s)
 				goto fp_not_useful;
-			if (str_equal(fp->fingerprint, s))
+			if (str_equal(fp->contents_fingerprint, s))
 			{
 				/*
 				 * the fingerprint is the same,
 				 * so give the oldest mtime
 				 * known
 				 */
-				fp_value_constructor3
+				fp_value_constructor4
 				(
 					&data,
 					fp->oldest,
 					cp->newest,
-					s
+					s,
+					fp->ingredients_fingerprint
 				);
 				str_free(s);
 				cp->oldest = fp->oldest;
@@ -242,12 +244,13 @@ stat_cache_fingerprint(path, cp)
 				 * the fingerprint differs
 				 * do not lie about mtime
 				 */
-				fp_value_constructor3
+				fp_value_constructor4
 				(
 					&data,
 					cp->newest,
 					cp->newest,
-					s
+					s,
+					fp->ingredients_fingerprint
 				);
 				str_free(s);
 			}
@@ -385,7 +388,7 @@ stat_cache(path, cp, follow_links)
 			st.st_mtime = 1;
 		cp->oldest = st.st_mtime;
 		cp->newest = st.st_mtime;
-		
+
 		/*
 		 * see if we have its fingerprint on file
 		 */
@@ -658,12 +661,13 @@ stat_cache_set(path, when, fp2)
 		{
 			fp_value_ty	data;
 
-			fp_value_constructor3
+			fp_value_constructor4
 			(
 				&data,
-				fp->oldest, 
+				fp->oldest,
 				when,
-				fp->fingerprint
+				fp->contents_fingerprint,
+				fp->ingredients_fingerprint
 			);
 			fp_assign(path, &data);
 			fp_value_destructor(&data);
