@@ -1,7 +1,7 @@
 #!/bin/sh
 #
 #	cook - file construction tool
-#	Copyright (C) 1990, 1991, 1992, 1993, 1994, 1995, 1996, 1997, 1998, 1999 Peter Miller;
+#	Copyright (C) 1994, 1995, 1996, 1997, 1998, 1999, 2001 Peter Miller;
 #	All rights reserved.
 #
 #	This program is free software; you can redistribute it and/or modify
@@ -137,8 +137,10 @@ ${stem}.gen.\$(OBJEXT)"
 	lib/*/*/main.*)
 		stem=`echo $file | sed 's|^lib/\(.*\)/main.*$|\1|'`
 		groff_all="$groff_all lib/$stem.ps lib/$stem.dvi lib/$stem.txt"
-		clean_files="$clean_files lib/$stem.ps lib/$stem.dvi lib/$stem.txt"
-		groff_install="$groff_install \$(datadir)/$stem.ps \$(datadir)/$stem.dvi \$(datadir)/$stem.txt"
+		clean_files="$clean_files \
+lib/$stem.ps lib/$stem.dvi lib/$stem.txt"
+		groff_install="$groff_install \$(datadir)/$stem.ps \
+\$(datadir)/$stem.dvi \$(datadir)/$stem.txt"
 		;;
 
 	lib/*)
@@ -164,17 +166,21 @@ do
 
 	echo ""
 	echo "bin/${prog}\$(EXEEXT): \$(${prog}_obj) common/lib.\$(LIBEXT) .bin"
-	echo "	\$(CC) \$(LDFLAGS) -o \$@ \$(${prog}_obj) common/lib.\$(LIBEXT) \$(LIBS)"
+	echo "	\$(CC) \$(LDFLAGS) -o \$@ \$(${prog}_obj) \
+common/lib.\$(LIBEXT) \$(LIBS)"
 
 	all="${all} bin/${prog}\$(EXEEXT)"
 
 	if test "$prog" = fstrcmp; then continue; fi
+	if test "$prog" = file_check; then continue; fi
 
 	echo ""
-	echo "\$(bindir)/\$(PROGRAM_PREFIX)${prog}\$(PROGRAM_SUFFIX)\$(EXEEXT): bin/${prog}\$(EXEEXT) .bindir"
+	echo "\$(bindir)/\$(PROGRAM_PREFIX)${prog}\$(PROGRAM_SUFFIX)\$(EXEEXT):\
+ bin/${prog}\$(EXEEXT) .bindir"
 	echo "	\$(INSTALL_PROGRAM) bin/${prog}\$(EXEEXT) \$@"
 
-	install_bin="${install_bin} \$(bindir)/\$(PROGRAM_PREFIX)${prog}\$(PROGRAM_SUFFIX)\$(EXEEXT)"
+	install_bin="${install_bin} \
+\$(bindir)/\$(PROGRAM_PREFIX)${prog}\$(PROGRAM_SUFFIX)\$(EXEEXT)"
 done
 
 echo ""
