@@ -1,6 +1,6 @@
 /*
  *	cook - file construction tool
- *	Copyright (C) 1994, 1997, 1998 Peter Miller;
+ *	Copyright (C) 1994, 1997, 1998, 2001 Peter Miller;
  *	All rights reserved.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -91,7 +91,7 @@ init()
 
 	if (symtab)
 		return;
-	trace(("init()\n{\n"/*}*/));
+	trace(("init()\n{\n"));
 	symtab = symtab_alloc(SIZEOF(table));
 	for (tp = table; tp < ENDOF(table); ++tp)
 	{
@@ -100,7 +100,7 @@ init()
 		symtab_assign(symtab, name, value);
 		str_free(name);
 	}
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -111,7 +111,7 @@ vargram_lookup(name)
 	string_ty	*data;
 	string_ty	*retval;
 
-	trace(("vargram_lookup(\"%s\")\n{\n"/*}*/, name->str_text));
+	trace(("vargram_lookup(\"%s\")\n{\n", name->str_text));
 	assert(symtab);
 	data = 0;
 	if (special)
@@ -126,7 +126,7 @@ vargram_lookup(name)
 		retval = str_format("[%S]", name);
 	}
 	trace(("return \"%s\";\n", retval->str_text));
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 	return retval;
 }
 
@@ -191,7 +191,7 @@ vargram_lex()
 	int		token;
 	int		quote_spaces;
 
-	trace(("vargram_lex()\n{\n"/*}*/));
+	trace(("vargram_lex()\n{\n"));
 	quote_spaces = (lex_quote_spaces && (lex_depth <= 0));
 	c = (unsigned char)*lexpos++;
 	trace(("c = '%s';\n", unctrl(c)));
@@ -207,17 +207,17 @@ vargram_lex()
 			--lexpos;
 			token = 0;
 			break;
-	
+
 		case '$':
 			token = DOLLAR;
 			break;
-	
-		case '('/*)*/:
+
+		case '(':
 			++lex_depth;
 			token = LP;
 			break;
-	
-		case '{'/*}*/:
+
+		case '{':
 			++lex_depth;
 			token = LB;
 			break;
@@ -259,12 +259,12 @@ vargram_lex()
 			buf[len++] = '\\';
 			buf[len++] = c;
 			break;
-	
+
 		case '\b':
 			buf[len++] = '\\';
 			buf[len++] = 'b';
 			break;
-	
+
 		case '\f':
 			if (!quote_spaces)
 			{
@@ -274,7 +274,7 @@ vargram_lex()
 			buf[len++] = '\\';
 			buf[len++] = 'f';
 			break;
-	
+
 		case '\n':
 			if (!quote_spaces)
 			{
@@ -284,12 +284,12 @@ vargram_lex()
 			buf[len++] = '\\';
 			buf[len++] = 'n';
 			break;
-	
+
 		case '\r':
 			buf[len++] = '\\';
 			buf[len++] = 'r';
 			break;
-	
+
 		case '\t':
 			if (!quote_spaces)
 			{
@@ -299,14 +299,14 @@ vargram_lex()
 			buf[len++] = '\\';
 			buf[len++] = 't';
 			break;
-	
+
 #if __STDC__ >= 1
 		case '\v':
 			buf[len++] = '\\';
 			buf[len++] = 'v';
 			break;
 #endif
-	
+
 		case '"':
 		case '\'':
 			/*
@@ -317,21 +317,21 @@ vargram_lex()
 				buf[len++] = '\\';
 			buf[len++] = c;
 			break;
-	
+
 		case ';':
 		case ':':
 		case '=':
 		case '\\':
-		case '{'/*}*/:
-		case /*{*/'}':
-		case '['/*]*/:
-		case /*[*/']':
+		case '{':
+		case '}':
+		case '[':
+		case ']':
 			/* characters with special meaning to cook */
 			buf[len++] = '\\';
 			buf[len++] = c;
 			break;
-	
-		case '('/*)*/:
+
+		case '(':
 			if (allow_archive_parens && (lex_depth <= 0))
 			{
 				token = LP;
@@ -345,9 +345,19 @@ vargram_lex()
 			if (!isprint(c))
 			{
 				buf[len++] = '\\';
-				if (isdigit((unsigned char)*lexpos) || (c & 0300))
+				if
+				(
+					isdigit((unsigned char)*lexpos)
+				||
+					(c & 0300)
+				)
 					buf[len++] = '0' + ((c >> 6) & 3);
-				if (isdigit((unsigned char)*lexpos) || (c & 0370))
+				if
+				(
+					isdigit((unsigned char)*lexpos)
+				||
+					(c & 0370)
+				)
 					buf[len++] = '0' + ((c >> 3) & 7);
 				buf[len++] = '0' + (c & 7);
 			}
@@ -370,24 +380,24 @@ vargram_lex()
 			--lexpos;
 			token = 0;
 			break;
-	
+
 		case '$':
 			token = DOLLAR;
 			lex_after_dollars = 1;
 			break;
-	
+
 		case ':':
 			token = COLON;
 			break;
-	
+
 		case '=':
 			token = EQU;
 			break;
-	
+
 		case ',':
 			token = COMMA;
 			break;
-	
+
 		case ' ':
 		case '\f':
 		case '\n':
@@ -408,7 +418,7 @@ vargram_lex()
 #endif
 					++lexpos;
 					continue;
-	
+
 				default:
 					break;
 				}
@@ -416,23 +426,23 @@ vargram_lex()
 			}
 			token = SPACE;
 			break;
-	
-		case '('/*)*/:
+
+		case '(':
 			++lex_depth;
 			token = LP;
 			break;
-	
-		case /*(*/')':
+
+		case ')':
 			--lex_depth;
 			token = RP;
 			break;
-	
-		case '{'/*}*/:
+
+		case '{':
 			token = LB;
 			--lex_depth;
 			break;
-	
-		case /*{*/'}':
+
+		case '}':
 			token = RB;
 			--lex_depth;
 			break;
@@ -444,7 +454,7 @@ vargram_lex()
 
 	done:
 	trace(("return %d;\n", token));
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 	return token;
 }
 
@@ -474,7 +484,7 @@ vargram_result(s)
 	static string_ty *t2;
 	string_ty	*tmp;
 
-	trace(("vargram_result(\"%s\")\n{\n"/*}*/, s->str_text));
+	trace(("vargram_result(\"%s\")\n{\n", s->str_text));
 	if (!s->str_length)
 	{
 		str_free(s);
@@ -489,7 +499,7 @@ vargram_result(s)
 	str_free(s);
 	string_list_append(&result, tmp);
 	str_free(tmp);
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
@@ -502,7 +512,8 @@ variable_rename(in, out, ref, flags)
 {
 	size_t		j;
 
-	trace(("variable_rename(in = %08lX, out = %08lX, ref = %08lX)\n{\n"/*}*/, (long)in, (long)out, (long)ref));
+	trace(("variable_rename(in = %08lX, out = %08lX, ref = %08lX)\n{\n",
+		(long)in, (long)out, (long)ref));
 	trace_string(in->text->str_text);
 	init();
 	source = in;
@@ -553,7 +564,7 @@ variable_rename(in, out, ref, flags)
 		symtab_free(special);
 		special = 0;
 	}
-	trace((/*{*/"}\n"));
+	trace(("}\n"));
 }
 
 
